@@ -4,6 +4,8 @@ import time
 import os
 import re
 
+from datetime import datetime
+
 import quantum_lab.resources as res
 
 class quantum_lab():
@@ -74,22 +76,22 @@ class quantum_lab():
 
         body = json.dumps({
             "resource": {
-                "id": self.resourceID,
+                "id": self.resourceId,
                 "name": self.resourceName
             },
-            "type": uploadType,
+            "type": uploadType.upper(),
             "filePath": filePath,
             "shot": shot,
         })
 
         response = requests.post(f"{url_path}", headers=headers, data=body) 
-        if response.status_code != 200:
+        if response.status_code >= 400:
             return self.error_handler(response)
         
         data = response.json()
         
-        print("{:<6} {:<15}".format("ID", "Created Status"))
-        print("{:<6} {:<15}".format(data["id"], data["status"]))
+        print("{:<40} {:<10}".format("ID", "Created Status"))
+        print("{:<40} {:<10}".format(data["id"], data["status"]))
 
         jobID = data["id"]
 
@@ -136,31 +138,22 @@ class quantum_lab():
 
         body = json.dumps({
             "resource": {
-                "id": self.resourceID,
+                "id": self.resourceId,
                 "name": self.resourceName
             },
-            "type": uploadType,
+            "type": uploadType.upper(),
             "filePath": filePath,
             "shot": shot,
         })
 
-        body = json.dumps({
-            "uploadType": uploadType,
-            "shot": shot,
-            "resourceId": self.resourceId,
-            "filePath": filePath,
-            "volumeName": self.volumeName,
-            "resourceName": self.resourceName
-        })
-
         response = requests.post(f"{url_path}", headers=headers, data=body) 
-        if response.status_code != 200:
+        if response.status_code >= 400:
             return self.error_handler(response)
         
         data = response.json()
         
-        print("{:<6} {:<15}".format("ID", "Created Status"))
-        print("{:<6} {:<15}".format(data["id"], data["status"]))
+        print("{:<40} {:<10}".format("ID", "Created Status"))
+        print("{:<40} {:<10}".format(data["id"], data["status"]))
         
         return data["id"]
 
@@ -177,8 +170,8 @@ class quantum_lab():
             return self.error_handler(response)
         
         data = response.json()
-
-        print("{:<5} {:<12} {:<9} {:<5} {:<10} {:<20} {:<30}".format(
+            # {:<40} {:<15} {:<10} {:<10} {:<10}
+        print("{:<40} {:<15} {:<10} {:<5} {:<10} {:<20} {:<30}".format(
             "ID", 
             # "JobID", 
             # "ResourceID", 
@@ -192,7 +185,7 @@ class quantum_lab():
         )
         index = 0
         for ele in data["content"]:
-            print("{:<5} {:<12} {:<9} {:<5} {:<10} {:<20} {:<30}".format(
+            print("{:<40} {:<15} {:<10} {:<5} {:<10} {:<20} {:<30}".format(
                 ele["id"], 
                 # ele["jobId"], 
                 # ele["resourceId"], 
@@ -201,7 +194,7 @@ class quantum_lab():
                 ele["shot"],
                 ele["type"],
                 ele["filePath"].split('/')[-1],
-                ele["createdAt"]
+                datetime.fromtimestamp(int(ele["createdAt"]))
                 )
             )
             index += 1 
@@ -210,62 +203,58 @@ class quantum_lab():
 
         return 1
 
-    def getJob(self, id: int):
-        url_path = f"{self.url}/qcc/notebook/job/{id}"
+    def getJob(self, id: str):
+        url_path = f"{self.url}/v1/jobs/{id}"
 
         headers = {
             "Content-Type": "application/json",
-            "email": self.userID,
+            "emailId": self.userID,
         }
         response = requests.get(f"{url_path}", headers=headers)
         
-        if response.status_code != 200:
+        if response.status_code >= 400:
             return self.error_handler(response)
 
         data = response.json()
-        print("{:<5} {:<10} {:<10} {:<12} {:<9} {:<8} {:<5} {:<11} {:<17} {:<30} {:<30}".format(
+        print("{:<40} {:<15} {:<10} {:<5} {:<10} {:<20} {:<30}".format(
             "ID", 
-            "JobID", 
-            "ResourceID", 
+            # "JobID", 
+            # "ResourceID", 
             "ResourceName", 
-            "RegStatus", 
             "Status", 
             "Shot",
-            "UploadType",
+            "Type",
             "FilePath", 
-            "CreatedAt",
-            "RunningAt"
+            "CreatedAt"
             )
         )
-        print("{:<5} {:<10} {:<10} {:<12} {:<9} {:<8} {:<5} {:<11} {:<17} {:<30} {:<30}".format(
+        print("{:<40} {:<15} {:<10} {:<5} {:<10} {:<20} {:<30}".format(
             data["id"], 
-            data["jobId"], 
-            data["resourceId"], 
-            data["resourceName"], 
-            'True' if data["jobRegStatus"] else 'False', 
-            'NotReady' if data["jobStatus"] is None else data["jobStatus"],
-            data["jobShot"],
-            data["jobUploadType"],
-            data["jobFilePath"].split('/')[-1],
-            data["createdAt"],
-            'NotReady' if data["runningAt"] is None else data["runningAt"]
+            # ele["jobId"], 
+            # ele["resourceId"], 
+            data["resource"]["name"], 
+            data["status"],
+            data["shot"],
+            data["type"],
+            data["filePath"].split('/')[-1],
+            datetime.fromtimestamp(int(data["createdAt"]))
             )
         )
         
         return data
 
     def delete(self, id: str):
-        url_path = f"{self.url}/qcc/notebook/job/{id}"
+        url_path = f"{self.url}/v1/jobs/{id}"
 
         headers = {
             "Content-Type": "application/json",
-            "email": self.userID,
+            "emailId": self.userID,
         }
         response = requests.delete(f"{url_path}", headers=headers)
 
-        if response.status_code != 200:
+        if response.status_code >= 400:
             return self.error_handler(response)
 
-        print(f"Deleted job : {response.text}")
+        print(f"Deleted job : {id}")
 
         return response.text
